ListenersState class

Constructors

ListenersState()

Properties

hashCode int
The hash code for this object.
no setterinherited
obj Map<String, Map<String, dynamic>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String id, dynamic state) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String id, dynamic state) → void
toString() String
A string representation of this object.
inherited
update(String id) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited